pub struct DecodingTemplate {
pub scope_fields_specs: Box<[FieldSpecifier]>,
pub fields_specs: Box<[FieldSpecifier]>,
pub processed_count: u64,
}Expand description
Simpler template that is used to decode data records
Fields
scope_fields_specs: Box<[FieldSpecifier]>fields_specs: Box<[FieldSpecifier]>processed_count: u64Number of Data Records processed using this template
Implementations
Sourceimpl DecodingTemplate
impl DecodingTemplate
pub const fn new( scope_fields_specs: Box<[FieldSpecifier]>, fields_specs: Box<[FieldSpecifier]>, ) -> Self
Sourcepub const fn increment_processed_count(&mut self)
pub const fn increment_processed_count(&mut self)
Increment Data Record count by one
Sourcepub const fn processed_count(&self) -> u64
pub const fn processed_count(&self) -> u64
Get the current processed Data Record count
Sourcepub const fn reset_processed_count(&mut self) -> u64
pub const fn reset_processed_count(&mut self) -> u64
Get the current processed Data Record count and reset the value to zero